Описание действий
-В Altium открываем sch компонента
-В Altium DXP/Run Script выбираем Import_pins_Altium/ImportPins.PRJSCR(есть в архиве pybga-*.tar.gz)
-Запускаем RunImportPins
-Выбираем ./pins_out.csv